@@ -65,7 +65,7 @@ class Spectrogram:
     crop(frequency_min, frequency_max)
         Crop frequencies from the spectrogram.
     denoise(method, **kwargs)
-        Denoise the spectrogram using various methods. 
+        Denoise the spectrogram using various methods.
         Methods implemented:
         METHODS           :    INPUT ARGUMENTS
         'median_equalizer':    window_duration in seconds.
@@ -73,7 +73,7 @@ class Spectrogram:
 
     _valid_units = ('samp', 'sec')
     _valid_windows = ('hann',)
-    def __init__(self, frame, window_type, fft, step, sampling_frequency, unit='sec'):
+    def __init__(self, frame, window_type, fft, step, sampling_frequency, unit='sec', verbose=True):
         """
         Initialize Spectrogram object.
 
@@ -93,13 +93,15 @@ class Spectrogram:
             Size of the Fast Fourier Transform, in seconds or samples,
             depending on 'unit'.
         step : float
-            Time step between conscutive spectrogram frames. In samples or 
+            Time step between conscutive spectrogram frames. In samples or
             seconds depending on 'unit'.
         sampling_frequency : float
             Sampling frequency of the signal, in Hz.
         unit : str, optional
             Unit used when defining the 'frame' and 'fft' parameters. For
             seconds, use 'sec'. For samples, use 'samp'. The default is 'sec'.
+        verbose : bool
+            if True, prints all notification messages. The default is True.
 
         Returns
         -------
@@ -117,7 +119,7 @@ class Spectrogram:
         # Convert units in seconds/samples
         self._frame_samp, self._fft_samp, self._step_samp, self._frame_sec,\
         self._fft_sec, self._step_sec, self._overlap_perc, self._overlap_samp =\
-        Spectrogram._convert_units(frame, fft, step, sampling_frequency, unit)
+        Spectrogram._convert_units(frame, fft, step, sampling_frequency, unit, verbose=verbose)
 
         # Time and frequency resolution
         self._sampling_frequency = sampling_frequency
@@ -130,22 +132,23 @@ class Spectrogram:
         self._axis_frequencies = []
         self._axis_times = []
 
-    def _convert_units(frame, fft, step, sampling_frequency, unit):
+    def _convert_units(frame, fft, step, sampling_frequency, unit, verbose=True):
         """Convert frame, fft, and step values to samples/seconds"""
         if unit == 'sec':
             frame_samp = round(frame*sampling_frequency)
-            fft_samp = adjust_FFT_size(round(fft*sampling_frequency))
+            fft_samp = adjust_FFT_size(round(fft*sampling_frequency),verbose=verbose)
             step_samp = round(step*sampling_frequency)
             frame_sec = frame
             fft_sec = fft_samp*sampling_frequency
             step_sec = step
         elif unit == 'samp':
             frame_samp = frame
-            fft_samp = adjust_FFT_size(fft)
+            fft_samp = adjust_FFT_size(fft,verbose=verbose)
             step_samp = step
             frame_sec = frame/sampling_frequency
             fft_sec = fft_samp/sampling_frequency
             step_sec = step/sampling_frequency
+
         overlap_samp = frame_samp-step_samp
         overlap_perc = (overlap_samp/frame_samp)*100
         return frame_samp, fft_samp, step_samp, frame_sec, fft_sec, step_sec, overlap_perc,overlap_samp
@@ -338,18 +341,18 @@ class Spectrogram:
         if inplace:
             # self._axis_frequencies = self._axis_frequencies[min_row_idx:max_row_idx]
             # self._axis_times = np.arange(0,(max_col_idx - min_col_idx)*self._time_resolution,self._time_resolution)
-            # self._spectrogram = self._spectrogram[min_row_idx:max_row_idx, min_col_idx:max_col_idx]   
+            # self._spectrogram = self._spectrogram[min_row_idx:max_row_idx, min_col_idx:max_col_idx]
             # out_object = None
             self._axis_frequencies = self._axis_frequencies[min_row_idx:max_row_idx+1]
             self._axis_times = self._axis_times[min_col_idx:max_col_idx+1]-self._axis_times[min_col_idx]
-            self._spectrogram = self._spectrogram[min_row_idx:max_row_idx+1, min_col_idx:max_col_idx+1]   
+            self._spectrogram = self._spectrogram[min_row_idx:max_row_idx+1, min_col_idx:max_col_idx+1]
             out_object = None
         else:
             out_object = copy.copy(self)
             out_object._axis_frequencies = out_object._axis_frequencies[min_row_idx:max_row_idx+1]
             #out_object._axis_times = np.arange(0,(max_col_idx - min_col_idx)*out_object._time_resolution,out_object._time_resolution)
             out_object._axis_times = out_object._axis_times[min_col_idx:max_col_idx+1]-out_object._axis_times[min_col_idx]
-            #out_object._spectrogram = out_object._spectrogram[min_row_idx:max_row_idx, min_col_idx:max_col_idx]   
+            #out_object._spectrogram = out_object._spectrogram[min_row_idx:max_row_idx, min_col_idx:max_col_idx]
             out_object._spectrogram = out_object._spectrogram[min_row_idx:max_row_idx+1, min_col_idx:max_col_idx+1]
             if out_object._spectrogram.shape[1] != len(out_object._axis_times):
                 raise ValueError("Spectrogram axes don't match spectrogram matrix.")
@@ -363,7 +366,7 @@ class Spectrogram:
         are:
             METHODS           :    INPUT ARGUMENTS
             'median_equalizer':    window_duration in seconds.
-                                   inplace 
+                                   inplace
 
         Parameters
         ----------
@@ -433,7 +436,7 @@ class Spectrogram:
         else:
             out_object = copy.copy(self)
             out_object._spectrogram = out_object._spectrogram-Smed
-            out_object._spectrogram[out_object._spectrogram < 0] = 0  # floor            
+            out_object._spectrogram[out_object._spectrogram < 0] = 0  # floor
         return out_object
 
     @property
@@ -511,11 +514,12 @@ class Spectrogram:
         """Return the spectrogram attribute."""
         return self._spectrogram
 
-def adjust_FFT_size(nfft):
+def adjust_FFT_size(nfft, verbose=True):
         """ Adjust nfft to the next power of two if necessary."""
         nfft_adjusted = next_power_of_2(nfft)
         if nfft_adjusted != nfft:
-            print('Warning: FFT size automatically adjusted to', nfft_adjusted, 'samples (original size:', nfft,')')
+            if verbose:
+                print('Warning: FFT size automatically adjusted to', nfft_adjusted, 'samples (original size:', nfft,')')
         return nfft_adjusted
 
 def next_power_of_2(x):
